<?php
/**
 * WeCodeArt Framework.
 *
 * WARNING: This file is part of the core WeCodeArt Framework. DO NOT edit this file under any circumstances.
 * Please do all modifications in the form of a child theme.
 *
 * @package 	WeCodeArt Framework
 * @subpackage 	Core\Author
 * @copyright   Copyright (c) 2019, WeCodeArt Framework
 * @since		3.7.7
 */

namespace WeCodeArt\Core;

if ( ! defined( 'ABSPATH' ) ) exit();

use WeCodeArt\Utilities\Markup;
use WeCodeArt\Utilities\Markup\SVG;

/**
 * Adds some output to archive pages
 */
class Author {

	use \WeCodeArt\Singleton;

	/**
	 * Do author box on archive
	 * 
	 * @since	3.7.7
	 */
	public function author_box_archive() {
		$enabled = apply_filters( 'wecodeart/filter/author/box/archive/enabled', '__return_true' );

		if ( ! $enabled || ( ! is_author() || get_query_var( 'paged' ) >= 2 ) ) {
			return;
		}

		self::render_box( 'archive' );
	}

	/**
	 * Do author box on single
	 * 
	 * @since	3.7.7
	 */
	public function author_box_single() {
		$enabled = apply_filters( 'wecodeart/filter/author/box/single/enabled', '__return_true' );

		if ( ! $enabled || ( ! is_single() || ! post_type_supports( get_post_type(), 'author' ) ) ) {
			return;
		}

		self::render_box( 'single' );
	}

	/**
	 * Echo the Author Box
	 *
	 * @since	3.7.7
	 *
	 * @return 	void 
	 */
	public static function render_box( $context ) {
		$enabled = apply_filters( 'wecodeart/filter/author/box/enabled', '__return_true' );

		if( ! $enabled || ! self::get_data( $context ) ) return;

		Markup::template( 'author/box', self::get_data( $context ) );
	}

	/**
	 * Get Author Information
	 *
	 * @since 	3.7.7
	 *
	 * @return 	array 
	 */
	public static function get_data( $context = '' ) {
		$avatar_size = apply_filters( 'wecodeart/filter/author/box/gravatar_size', 100 );

		$author = [
			'icon'			=> SVG::compile( 'icon--user' ),
			'intro' 		=> is_author() ? __( 'All articles by', 'wecodeart' ) : __( 'About', 'wecodeart' ),
			'name'			=> get_the_author(),
			'avatar' 		=> get_avatar( get_the_author_meta( 'email' ), $avatar_size, '', get_the_author() . "'s gravatar" ),
			'description'	=> wpautop( get_the_author_meta( 'description' ) ),
			'url'			=> get_author_posts_url( get_the_author_meta( 'ID' ) ),
			'website'		=> [
				'icon' 	=> SVG::compile( 'icon--globe' ),
				'label'	=> esc_html__( 'Website', 'wecodeart' )
			],
			'container' 	=> ! is_single() ? get_theme_mod( 'content-layout-container' ) : 'container-full'
		];

		if ( is_singular() ) {
			$author['name']	= sprintf( 
				'<a href="%s" rel="author nofollow">%s</a>', 
				esc_url( $author['url'] ), esc_html( $author['name'] ) 
			);
		}

		if ( 0 === mb_strlen( $author['name'] ) || 0 === mb_strlen( $author['description'] ) ) return [];

		return apply_filters( 'wecodeart/filter/author/box/context', $author, $context );
	} 
}